crystal_toolkit.renderables.structuregraph module — Crystal Toolkit documentation

# crystal_toolkit.renderables.structuregraph module

crystal_toolkit.renderables.structuregraph.get_structure_graph_scene(self, origin=None, draw_image_atoms=True, bonded_sites_outside_unit_cell=True, hide_incomplete_edges=False, incomplete_edge_length_scale=0.3, color_edges_by_edge_weight=False, edge_weight_color_scale='coolwarm', explicitly_calculate_polyhedra_hull=False, legend: Legend | None = None, group_by_site_property: str | None = None, bond_radius: float = 0.1) → Scene